@@ -6,18 +6,26 @@ from pulsar.schema import (
 )
 
 
-class TextSchema(Record):
+class TextItem(Record):
     uuid = String(required=True)
     text = String()
     sequence_id = String()
 
 
-class TextEmbeddingSchema(Record):
+class TextEmbeddingItem(Record):
     uuid = String(required=True)
     text = String()
     embedding = Array(Float())
 
 
+class TextSchema(Record):
+    items = Array(TextItem)
+
+
+class TextEmbeddingSchema(Record):
+    items = Array(TextEmbeddingItem())
+
+
 class TaskSchema(Record):
     task_class = String(required=True)
     task_id = String()
